C     ### Dimensions
      DIMENSION STAR1(1200,6),STAR2(1200,6)
      REAL M1,M2

C     ### Constants
      PI=4.*ATAN(1.)
      G=2.

C     ### Initial values
      M1=0.3
      M2=0.3
      MAX=1800
      DT=0.5
      EPSPAR=0.01
      EPSGAL=0.001
      U1=-0.03
      V1=-0.06
      W1=0.
      X1=+22.5
      Y1=0.
      Z1=0.
      U2=+0.03
      V2=+0.06
      W2=0.
      X2=-22.5
      Y2=0.
      Z2=0.
      N=0

C     ### Both galaxies consists out of 7 circles
      DO 20 ICIRC=1,7

C     ### Particles on every circle have same distance
      DO 10 IRNO=1,ICIRC*40
      N=N+1
      PHI=(2.*PI*REAL(IRNO-1))/REAL(ICIRC*40)

C     ### 7 circles over 12 kpc radius
      R=REAL(ICIRC)*(12./7.)

C     ### Position of particles (radius 12 kpc)
      X=R*COS(PHI)
      Y=R*SIN(PHI)
      Z=0.

C     ### Velocity of particles a
      VC=SQRT(G*M1/R)
      U=-VC*SIN(PHI)
      V=VC*COS(PHI)
      W=0.

C     ### Generate initial values of particles a
      STAR1(N,1)=X+X1
      STAR1(N,2)=Y+Y1
      STAR1(N,3)=Z+Z1
      STAR1(N,4)=U+U1
      STAR1(N,5)=V+V1
      STAR1(N,6)=W+W1

C     ### Velocity of particles b
      VC=SQRT(G*M2/R)
      U=-VC*SIN(PHI)
      V=VC*COS(PHI)
      W=0.

C     ### Generate initial values of particles b
      STAR2(N,1)=X+X2
      STAR2(N,2)=Y+Y2
      STAR2(N,3)=Z+Z2
      STAR2(N,4)=U+U2
      STAR2(N,5)=V+V2
      STAR2(N,6)=W+W2
   10 CONTINUE
   20 CONTINUE
      INUM1=N
      INUM2=N
      DO 40 J=1,MAX
      DO 30 I=1,INUM1

C     ### Softed distance between particle a and center 1
      F1=(STAR1(I,1)-X1)*(STAR1(I,1)-X1)
     $  +(STAR1(I,2)-Y1)*(STAR1(I,2)-Y1)
     $  +(STAR1(I,3)-Z1)*(STAR1(I,3)-Z1)+EPSPAR*EPSPAR
      F1=SQRT(F1)
      F1=F1*F1*F1

C     ### Softed distance between particle a and center 2
      F2=(STAR1(I,1)-X2)*(STAR1(I,1)-X2)
     $  +(STAR1(I,2)-Y2)*(STAR1(I,2)-Y2)
     $  +(STAR1(I,3)-Z2)*(STAR1(I,3)-Z2)+EPSPAR*EPSPAR
      F2=SQRT(F2)
      F2=F2*F2*F2

C     ### Components of accelleration particle a
      AX=-(G*M1*(STAR1(I,1)-X1))/F1-(G*M2*(STAR1(I,1)-X2))/F2
      AY=-(G*M1*(STAR1(I,2)-Y1))/F1-(G*M2*(STAR1(I,2)-Y2))/F2
      AZ=-(G*M1*(STAR1(I,3)-Z1))/F1-(G*M2*(STAR1(I,3)-Z2))/F2

C     ### Integration of trail particle a (Leap-Frog)
      STAR1(I,4)=STAR1(I,4)+AX*DT
      STAR1(I,5)=STAR1(I,5)+AY*DT
      STAR1(I,6)=STAR1(I,6)+AZ*DT
      STAR1(I,1)=STAR1(I,1)+STAR1(I,4)*DT
      STAR1(I,2)=STAR1(I,2)+STAR1(I,5)*DT
      STAR1(I,3)=STAR1(I,3)+STAR1(I,6)*DT
   30 CONTINUE
      DO 35 I=1,INUM2

C     ### Softed distance between particle b and center 1
      F1=(STAR2(I,1)-X1)*(STAR2(I,1)-X1)
     $  +(STAR2(I,2)-Y1)*(STAR2(I,2)-Y1)
     $  +(STAR2(I,3)-Z1)*(STAR2(I,3)-Z1)+EPSPAR*EPSPAR
      F1=SQRT(F1)
      F1=F1*F1*F1

C     ### Softed distance between particle b and center 2
      F2=(STAR2(I,1)-X2)*(STAR2(I,1)-X2)
     $  +(STAR2(I,2)-Y2)*(STAR2(I,2)-Y2)
     $  +(STAR2(I,3)-Z2)*(STAR2(I,3)-Z2)+EPSPAR*EPSPAR
      F2=SQRT(F2)
      F2=F2*F2*F2

C     ### Components of accelleration particle b
      AX=-(G*M1*(STAR2(I,1)-X1))/F1-(G*M2*(STAR2(I,1)-X2))/F2
      AY=-(G*M1*(STAR2(I,2)-Y1))/F1-(G*M2*(STAR2(I,2)-Y2))/F2
      AZ=-(G*M1*(STAR2(I,3)-Z1))/F1-(G*M2*(STAR2(I,3)-Z2))/F2

C     ### Integration of trail particle b (Leap-Frog)
      STAR2(I,4)=STAR2(I,4)+AX*DT
      STAR2(I,5)=STAR2(I,5)+AY*DT
      STAR2(I,6)=STAR2(I,6)+AZ*DT
      STAR2(I,1)=STAR2(I,1)+STAR2(I,4)*DT
      STAR2(I,2)=STAR2(I,2)+STAR2(I,5)*DT
      STAR2(I,3)=STAR2(I,3)+STAR2(I,6)*DT
   35 CONTINUE

C     ### Softed distance between center 1 and center 2
      F=(X1-X2)*(X1-X2)+(Y1-Y2)*(Y1-Y2)+(Z1-Z2)*(Z1-Z2)+EPSGAL*EPSGAL
      F=SQRT(F)
      F=F*F*F

C     ### Components of accelleration center 1
      AX1=-G*M2*(X1-X2)/F
      AY1=-G*M2*(Y1-Y2)/F
      AZ1=-G*M2*(Z1-Z2)/F

C     ### Integration of trail center 1 (Leap-Frog)
      U1=U1+AX1*DT
      V1=V1+AY1*DT
      W1=W1+AZ1*DT
      X1=X1+U1*DT
      Y1=Y1+V1*DT
      Z1=Z1+W1*DT

C     ### Components of accelleration center 2
      AX2=-G*M1*(X2-X1)/F
      AY2=-G*M1*(Y2-Y1)/F
      AZ2=-G*M1*(Z2-Z1)/F

C     ### Integration of trail center 2 (Leap Frog)
      U2=U2+AX2*DT
      V2=V2+AY2*DT
      W2=W2+AZ2*DT
      X2=X2+U2*DT
      Y2=Y2+V2*DT
      Z2=Z2+W2*DT
   40 CONTINUE
      STOP
      END
